ui-state-active, .ui-widget-content .ui-state-active, .ui-widget-header .ui-state-active, a.ui-button:active, .ui-button:active, .ui-button.ui-state-active:hover {
  border: 1px solid #3c8dbc !important;
  background: #3c8dbc44 !important;
  font-weight: normal !important;
  color: #ffffff !important;
}

/*# sourceMappingURL=ui.theme.lte.css.map */
